@@ -21,7 +21,6 @@ from ..advanced.packers import ClassificationDatabasePacker, ClassificationDatab
     DuplicateFeatureVectorsException, VirtualClassificationDatabasePacker
 from ..constants import RCDB
 from ..providers import AdminProvider, RetailerProvider, sleep
-from ..providers.facenet import FacenetProvider
 from ..utils import Timer, uri_validator, download_and_return_id, get_filename_from_url
 
 
@@ -166,70 +165,6 @@ def models(ctx, retailer):
         raise click.ClickException(exc)
 
 
-@api.command()
-@click.option('-r', '--retailer', help='Retailer codename')
-@click.option('-u', '--facenet-url', help='Facenet service URL')
-@click.argument('image_url')
-@pass_rebotics_context
-def extract_feature_vectors(ctx, retailer, facenet_url, image_url):
-    """Fetches latest configuration of neural model for retailer by it's ID and Secret key;
-    Sends image to facenet to load model into state."""
-    models = ctx.provider.get_retailer_tf_models(codename=retailer)
-
-    facenet_model = models['facenet_model']
-    if ctx.verbose:
-        click.echo("Facenet model: %s" % facenet_model['codename'])
-
-    facenet_provider = FacenetProvider(facenet_url)
-    feature_extractor = partial(
-        facenet_provider.extract_from_image_url,
-        model_path=facenet_model['data_path'],
-        index_path=facenet_model['index_path'],
-        meta_path=facenet_model['meta_path'],
-    )
-
-    with Timer() as t:
-        result = feature_extractor(image_url)
-        click.echo(result)
-
-    if ctx.verbose:
-        click.echo("Elapsed: %s seconds" % t.elapsed_secs)
-
-
-@api.command()
-@click.option('-r', '--retailer', help='Retailer')
-@click.option('-u', '--facenet-url', help='Facenet service URL')
-@click.argument('image_url')
-@click.argument('bounding_boxes', type=click.File())
-@pass_rebotics_context
-def extract_feature_vectors_for_boxes(ctx, retailer, facenet_url, image_url, bounding_boxes):
-    """Fetches latest configuration of neural model for retailer by it's ID and Secret key;
-    Sends keyframe image url and list of bounding boxes to facenet to load model into state."""
-    models = ctx.get_retailer_tf_models(codename=retailer)
-
-    facenet_model = models['facenet_model']
-    if ctx.verbose:
-        click.echo("Facenet model: %s" % facenet_model['codename'])
-
-    boxes = json.load(bounding_boxes)
-    assert isinstance(boxes, list), "Need to supply list of bounding boxes"
-
-    facenet_provider = FacenetProvider(facenet_url)
-    feature_extractor = partial(
-        facenet_provider.extract_from_keyframe,
-        model_path=facenet_model['data_path'],
-        index_path=facenet_model['index_path'],
-        meta_path=facenet_model['meta_path'],
-    )
-
-    with Timer() as t:
-        result = feature_extractor(keyframe_url=image_url, bboxes=boxes)
-        click.echo(result)
-
-    if ctx.verbose:
-        click.echo("Elapsed: %s seconds" % t.elapsed_secs)
-
-
 @api.command()
 @click.argument('retailer', type=click.STRING)
 @click.argument('url', type=click.STRING)
@@ -408,7 +343,7 @@ db/
 
 @api.group(name='rcdb')
 def rcdb_group():
-    pass
+    click.echo("RCDB in rebotics admin is deprecated and will be removed in version 0.13.0")
 
 
 @rcdb_group.command()
