@@ -62,22 +62,29 @@ def fix_pycharm(container, volume):
 
 
 @main.command()
-def fix_pycharm_clean():
+@click.option("-p", "--pycharm_folder", help="pycharm folder from where to start", type=click.Path())
+def fix_pycharm_clean(pycharm_folder):
     """
     This command fixes all pycharm related volumes and merges the helpers folder to it.
     This is in case when you update pycharm and run with debugger, but it yields error:
     python: can't open file '/opt/.pycharm_helpers/pydev/pydevd.py': [Errno 2] No such file or directory
+    python: can't open file '/opt/.pycharm_helpers/generator3/__main__.py': [Errno 2] No such file or directory
     """
 
-    def find_pycharm_helpers_folders():
-        for dirpath, dirnames, filenames in os.walk(os.path.expanduser('~')):
+    def find_pycharm_helpers_folders(base_folder):
+        for dirpath, dirnames, filenames in os.walk(os.path.expanduser(base_folder)):
             if 'PyCharm' in dirpath:
                 if '/helpers' in dirpath and '/helpers/' not in dirpath:  # get only the top folder
                     if 'pydev' in dirnames:
                         yield dirpath
 
     helper_folder = ''
-    for path in find_pycharm_helpers_folders():
+    if pycharm_folder is not None:
+        base_folder = pathlib.Path(pycharm_folder)
+    else:
+        base_folder = "~"
+
+    for path in find_pycharm_helpers_folders(base_folder):
         helper_folder = path
         break
     click.echo('Using helper folder: {helper_folder}'.format(
@@ -227,17 +234,20 @@ def option_default_from_configurations(conf_name):
 @click.option('-h', '--host', help='App host', prompt=True, cls=option_default_from_configurations('host'))
 @click.option('-u', '--user', prompt=True, cls=option_default_from_configurations('username'))
 @click.option('--password', prompt=True, hide_input=True, confirmation_prompt=False)
+@click.option('--verification_code', prompt=True)
 @pass_rebotics_context
-def configure(ctx, user, password, host):
-    """Fetch token, save it and use the role of it"""
+def configure(ctx, user, password, host, verification_code):
+    """Fetch token, save it and use the role of it.
+     Leave verification code empty"""
     provider = ctx.provider_class(host=host)
     ctx.update_configuration(
         host=host,
     )
     try:
-        response = provider.token_auth(user, password)
-    except ProviderHTTPClientException:
+        response = provider.token_auth(user, password, verification_code)
+    except ProviderHTTPClientException as e:
         click.echo('Failed to login')
+        click.echo(f'Exception: {e}')
         return
 
     ctx.update_configuration(
@@ -249,6 +259,22 @@ def configure(ctx, user, password, host):
     ctx.format_result(response)
 
 
+@click.command()
+@click.option('-h', '--host', help='App host', prompt=True, cls=option_default_from_configurations('host'))
+@click.option('--token', prompt=True, hide_input=True, confirmation_prompt=False)
+@pass_rebotics_context
+def set_token(ctx, host, token):
+    """
+    Set raw authorization token
+    """
+    ctx.update_configuration(
+        host=host,
+        date=datetime.now().strftime('%c'),
+        token=token,
+    )
+    click.echo('Saved configuration for {} in {}'.format(ctx.role, ctx.config_provider.filepath), err=True)
+
+
 @click.command()
 @click.argument('source_file', type=click.File('r'))
 @pass_rebotics_context
