@@ -171,7 +171,11 @@ def download_ref_backup(ctx, retailer, facenet, output):
 
 
 def task_download_and_set_training_data(item_id, target, ctx):
-    response = ctx.provider.get_detection_image_by_id(item_id)
+    try:
+        response = ctx.provider.get_detection_image_by_id(item_id)
+    except:
+        click.echo("Failed to find image with id={}".format(item_id))
+        return
     # download images and download this json
     image_url = response['image']
     json_file = target / "{}.json".format(item_id)
